@@ -38,7 +38,7 @@ class GoogleClientManager:
 
         self._logger = Client[Environment, Key](
             environment=self._application_context.environment,
-            service_key=self._application_context.key,
+            service_key=self._application_context.service_key,
             client_key=self._key,
             config=log_config,
         )
